import 'package:flutter/material.dart';
import 'package:flutter_chessboard_js/flutter_chessboard.dart';

/// Panel to display notation
class ChessboardNotation extends StatefulWidget {
  ChessboardNotation({
    required this.flipBoard,
    required this.height,
    required this.width,
    this.color = Colors.black,
    required this.controller,
    required this.notationTextColor,
  });

  final VoidCallback flipBoard;
  final double height;
  final double width;
  final Color color;
  final ChessboardController controller;
  final notationTextColor;

  @override
  _ChessboardNotationState createState() => _ChessboardNotationState();
}

class _ChessboardNotationState extends State<ChessboardNotation> {
  @override
  void initState() {
    widget.controller.addListener(() {
      if (mounted) setState(() {});
    });
    super.initState();
  }

  @override
  void didUpdateWidget(covariant ChessboardNotation oldWidget) {
    if (oldWidget.controller != this.widget.controller) {
      widget.controller.addListener(() {
        if (mounted) setState(() {});
      });
    }
    super.didUpdateWidget(oldWidget);
  }

  @override
  void dispose() {
    widget.controller.removeListener(() {});
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final moves = widget.controller.gameLogic.getHistorySAN();

    return Container(
      width: widget.width,
      height: widget.height,
      color: widget.color,
      child: Padding(
        padding: const EdgeInsets.all(8.0),
        child: Column(
          mainAxisSize: MainAxisSize.max,
          children: [
            Padding(
              padding: const EdgeInsets.all(8.0),
              child: Text('Notation', style: TextStyle(color: Colors.white)),
            ),
            if (moves.isNotEmpty)
              Expanded(
                child: SingleChildScrollView(
                  child: Column(
                    mainAxisSize: MainAxisSize.max,
                    children: [
                      ...buildNotationTile(moves),
                    ],
                  ),
                ),
              ),
            if (moves.isEmpty) Spacer(),
            Row(
              children: [
                IconButton(
                    onPressed: widget.flipBoard,
                    icon: Icon(
                      Icons.flip_camera_android,
                      color: widget.notationTextColor,
                    )),
              ],
            ),
          ],
        ),
      ),
    );
  }

  List<Widget> buildNotationTile(List<String> moves) {
    List<Widget> tiles = [];

    int count = 1;
    for (int i = 0; i < moves.length; i = i + 2) {
      final temp = Row(
        children: [
          Container(
              decoration: BoxDecoration(
                  border: Border(
                      right: BorderSide(color: widget.notationTextColor))),
              width: 25,
              child: Center(
                  child: Text('$count',
                      style: TextStyle(color: widget.notationTextColor)))),
          Expanded(
              flex: 2,
              child: Center(
                  child: Text(moves[i],
                      style: TextStyle(color: widget.notationTextColor)))),
          Expanded(
              flex: 2,
              child: (i + 1 < moves.length)
                  ? Center(
                      child: Text(moves[i + 1],
                          style: TextStyle(color: widget.notationTextColor)))
                  : const SizedBox())
        ],
      );
      tiles.add(temp);
      count++;
    }
    return tiles;
  }
}
