import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_chessboard_js/flutter_chessboard.dart';
import 'package:chessjs/chessjs.dart' as chessjs;
import '../chess_vectors/chess_vectors_flutter.dart';

/// Returns the board image
Image? getBoardImage(BoardType boardType) {
  switch (boardType) {
    case BoardType.brown:
      return Image.asset(
        "images/brown_board.png",
//          package: 'flutter_chess_board',
        fit: BoxFit.contain,
      );
    case BoardType.darkBrown:
      return Image.asset(
        "images/dark_brown_board.png",
//          package: 'flutter_chess_board',
        fit: BoxFit.cover,
      );
    case BoardType.green:
      return Image.asset(
        "images/green_board.png",
//          package: 'flutter_chess_board',
        fit: BoxFit.cover,
      );
    case BoardType.orange:
      return Image.asset(
        "images/orange_board.png",
//          package: 'flutter_chess_board',
        fit: BoxFit.cover,
      );
    default:
      return null;
  }
}

/// Show dialog when pawn reaches last square
Future<String?> promotionDialog(
    BuildContext context, ChessboardController controller) async {
  return showDialog<String>(
    context: context,
    barrierDismissible: false,
    builder: (BuildContext context) {
      final color = controller.gameLogic.turn;
      return AlertDialog(
        title: Text('Choose promotion'),
        content: Row(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
          children: <Widget>[
            InkWell(
              child: color == chessjs.WHITE ? WhiteQueen() : BlackQueen(),
              onTap: () {
                Navigator.of(context).pop("q");
              },
            ),
            InkWell(
              child: color == chessjs.WHITE ? WhiteRook() : BlackRook(),
              onTap: () {
                Navigator.of(context).pop("r");
              },
            ),
            InkWell(
              child: color == chessjs.WHITE ? WhiteBishop() : BlackBishop(),
              onTap: () {
                Navigator.of(context).pop("b");
              },
            ),
            InkWell(
              child: color == chessjs.WHITE ? WhiteKnight() : BlackKnight(),
              onTap: () {
                Navigator.of(context).pop("n");
              },
            ),
          ],
        ),
      );
    },
  ).then((value) {
    return value;
  });
}

/// Get image to display on square
Widget getImageToDisplay(
    {required double size,
    required ChessboardController game,
    required squareName}) {
  Widget imageToDisplay = const SizedBox();

  if (game.gameLogic.get(squareName) == null) {
    const SizedBox();
  }

  String piece =
      (game.gameLogic.get(squareName)!.color == chessjs.WHITE ? 'W' : 'B') +
          game.gameLogic.get(squareName)!.type.toUpperCase();

  switch (piece) {
    case "WP":
      imageToDisplay = WhitePawn(size: size);
      break;
    case "WR":
      imageToDisplay = WhiteRook(size: size);
      break;
    case "WN":
      imageToDisplay = WhiteKnight(size: size);
      break;
    case "WB":
      imageToDisplay = WhiteBishop(size: size);
      break;
    case "WQ":
      imageToDisplay = WhiteQueen(size: size);
      break;
    case "WK":
      imageToDisplay = WhiteKing(size: size);
      break;
    case "BP":
      imageToDisplay = BlackPawn(size: size);
      break;
    case "BR":
      imageToDisplay = BlackRook(size: size);
      break;
    case "BN":
      imageToDisplay = BlackKnight(size: size);
      break;
    case "BB":
      imageToDisplay = BlackBishop(size: size);
      break;
    case "BQ":
      imageToDisplay = BlackQueen(size: size);
      break;
    case "BK":
      imageToDisplay = BlackKing(size: size);
      break;
    default:
      imageToDisplay = const SizedBox();
  }

  return imageToDisplay;
}
